#this file uses the R scripts from Dr. Andre A. Rupp and Dr. Oliver Wilhelm; Available from:
#http://www.education.umd.edu/EDMS/fac/Rupp/R%20Files%20for%20Mplus%20Input%20File%20Generation.zip

#SET CURRENT DIRECTORY -----------------------------------------------------------------------------------
current_dir = "C:/Dropbox/NCME2016/Files/RDCMplus/RDCMplus"

#INITIALIZE ALL FUNCTIONS --------------------------------------------------------------------------------
#this routine: (1) formats the Chapter 9 data in accordance with the R functions expectations
#              (2) writes the Mplus script
#              (3) runs Mplus using the MplusAutomation package
#              (4) collects Mplus output

#load MplusAutomation:
if (tryCatch(require("MplusAutomation")) == FALSE){
  install.packages("MplusAutomation")
  library(MplusAutomation)
}

#set directory to location of example R script:
setwd(current_dir)

#read in R scripts from Rupp and Wilhelm:
source("Functions/MplusDCM.R")

#ANALYZE EXAMPLE DATA FILE ------------------------------------------------------------------------------

#read in original data and create id variable
ch9data = read.csv(file = "Data/ch9data.csv")

#read in qmatrix file
qmatrix = read.csv("Data/ch9qmatrix.csv")

analysis_folder = paste(current_dir, "Analyses", sep = "/")
setwd(analysis_folder)

#write data set to file for reading by function
write.table(x = ch9data[c("id", "X1", "X2", "X3", "X4", "X5", "X6", "X7")], file = "inputdata.dat", 
            col.names = FALSE, quote = FALSE, row.names = FALSE)

#create output file
myoutput = generate.mplus.input(filename_ds = "inputdata.dat", qmatrix = qmatrix[,2:4], input_file = "ch9mplus.inp", PreAddVars = "id")

#run Mplus
myanalysis = runModels(directory = analysis_folder, showOutput = TRUE)

#gather results
myresults = extractModelParameters(target=analysis_folder)
mysummaries = extractModelSummaries(target=analysis_folder)

#display LCDM item parameters:
myresults$unstandardized[which(myresults$unstandardized$paramHeader == "New.Additional.Parameters"),]
  
#display LCDM structrual parameters:
myresults$unstandardized[which(myresults$unstandardized$paramHeader == "Means"),]
